@@ -1,7 +1,7 @@
 import sys, os, platform
 import numpy
 from PyQt5.QtWidgets import QApplication, QSizePolicy
-from PyQt5.QtGui import QDoubleValidator
+
 from PyQt5 import QtGui, QtWidgets
 
 from orangewidget import gui
@@ -176,7 +176,7 @@ class OWsrcalc_idpower(XoppyWidget, WidgetDecorator):
         box1 = gui.widgetBox(box)
         self.id_RING_ENERGY = oasysgui.lineEdit(box1, self, "RING_ENERGY",
                      label=self.unitLabels()[idx], addSpace=False,
-                    valueType=float, validator=QDoubleValidator(), orientation="horizontal", labelWidth=250)
+                    valueType=float, orientation="horizontal", labelWidth=250)
         self.show_at(self.unitFlags()[idx], box1)
 
         ########
@@ -184,7 +184,7 @@ class OWsrcalc_idpower(XoppyWidget, WidgetDecorator):
         box1 = gui.widgetBox(box)
         self.id_RING_CURRENT = oasysgui.lineEdit(box1, self, "RING_CURRENT",
                      label=self.unitLabels()[idx], addSpace=False,
-                    valueType=float, validator=QDoubleValidator(), orientation="horizontal", labelWidth=250)
+                    valueType=float, orientation="horizontal", labelWidth=250)
         self.show_at(self.unitFlags()[idx], box1)
 
         ########
@@ -192,7 +192,7 @@ class OWsrcalc_idpower(XoppyWidget, WidgetDecorator):
         box1 = gui.widgetBox(box)
         self.id_KY = oasysgui.lineEdit(box1, self, "KY",
                      label=self.unitLabels()[idx], addSpace=False,
-                    valueType=float, validator=QDoubleValidator(), orientation="horizontal", labelWidth=250)
+                    valueType=float, orientation="horizontal", labelWidth=250)
         self.show_at(self.unitFlags()[idx], box1)
 
         ########
@@ -200,7 +200,7 @@ class OWsrcalc_idpower(XoppyWidget, WidgetDecorator):
         box1 = gui.widgetBox(box)
         self.id_KX = oasysgui.lineEdit(box1, self, "KX",
                      label=self.unitLabels()[idx], addSpace=False,
-                    valueType=float, validator=QDoubleValidator(), orientation="horizontal", labelWidth=250)
+                    valueType=float, orientation="horizontal", labelWidth=250)
         self.show_at(self.unitFlags()[idx], box1)
 
         ########
@@ -208,7 +208,7 @@ class OWsrcalc_idpower(XoppyWidget, WidgetDecorator):
         box1 = gui.widgetBox(box)
         self.id_NUMBER_OF_PERIODS = oasysgui.lineEdit(box1, self, "NUMBER_OF_PERIODS",
                      label=self.unitLabels()[idx], addSpace=False,
-                    valueType=float, validator=QDoubleValidator(), orientation="horizontal", labelWidth=250)
+                    valueType=float, orientation="horizontal", labelWidth=250)
         self.show_at(self.unitFlags()[idx], box1)
 
         ########
@@ -216,7 +216,7 @@ class OWsrcalc_idpower(XoppyWidget, WidgetDecorator):
         box1 = gui.widgetBox(box)
         self.id_PERIOD_LENGTH = oasysgui.lineEdit(box1, self, "PERIOD_LENGTH",
                      label=self.unitLabels()[idx], addSpace=False,
-                    valueType=float, validator=QDoubleValidator(), orientation="horizontal", labelWidth=250)
+                    valueType=float, orientation="horizontal", labelWidth=250)
         self.show_at(self.unitFlags()[idx], box1)
 
         ########
@@ -224,7 +224,7 @@ class OWsrcalc_idpower(XoppyWidget, WidgetDecorator):
         box1 = gui.widgetBox(box)
         self.id_SIGMAX = oasysgui.lineEdit(box1, self, "SIGMAX",
                      label=self.unitLabels()[idx], addSpace=False,
-                    valueType=float, validator=QDoubleValidator(), orientation="horizontal", labelWidth=250)
+                    valueType=float, orientation="horizontal", labelWidth=250)
         self.show_at(self.unitFlags()[idx], box1)
 
         ########
@@ -232,7 +232,7 @@ class OWsrcalc_idpower(XoppyWidget, WidgetDecorator):
         box1 = gui.widgetBox(box)
         self.id_SIGMAXP = oasysgui.lineEdit(box1, self, "SIGMAXP",
                      label=self.unitLabels()[idx], addSpace=False,
-                    valueType=float, validator=QDoubleValidator(), orientation="horizontal", labelWidth=250)
+                    valueType=float, orientation="horizontal", labelWidth=250)
         self.show_at(self.unitFlags()[idx], box1)
 
         ########
@@ -240,7 +240,7 @@ class OWsrcalc_idpower(XoppyWidget, WidgetDecorator):
         box1 = gui.widgetBox(box)
         self.id_SIGMAY = oasysgui.lineEdit(box1, self, "SIGMAY",
                      label=self.unitLabels()[idx], addSpace=False,
-                    valueType=float, validator=QDoubleValidator(), orientation="horizontal", labelWidth=250)
+                    valueType=float, orientation="horizontal", labelWidth=250)
         self.show_at(self.unitFlags()[idx], box1)
 
         ########
@@ -248,7 +248,7 @@ class OWsrcalc_idpower(XoppyWidget, WidgetDecorator):
         box1 = gui.widgetBox(box)
         self.id_SIGMAYP = oasysgui.lineEdit(box1, self, "SIGMAYP",
                      label=self.unitLabels()[idx], addSpace=False,
-                    valueType=float, validator=QDoubleValidator(), orientation="horizontal", labelWidth=250)
+                    valueType=float, orientation="horizontal", labelWidth=250)
         self.show_at(self.unitFlags()[idx], box1)
 
 
@@ -263,7 +263,7 @@ class OWsrcalc_idpower(XoppyWidget, WidgetDecorator):
         box1 = gui.widgetBox(box, orientation="horizontal")
         oasysgui.lineEdit(box1, self, "NUMBER_OF_HARMONICS",
                      label=self.unitLabels()[idx], addSpace=False,
-                    valueType=float, validator=QDoubleValidator(), orientation="horizontal", labelWidth=150)
+                    valueType=float, orientation="horizontal", labelWidth=150)
         self.show_at(self.unitFlags()[idx], box1)
 
         gui.button(box1 , self, "Guess", callback=self.guess_number_of_harmonics, height=25)
@@ -273,7 +273,7 @@ class OWsrcalc_idpower(XoppyWidget, WidgetDecorator):
         box1 = gui.widgetBox(box)
         oasysgui.lineEdit(box1, self, "SOURCE_SCREEN_DISTANCE",
                      label=self.unitLabels()[idx], addSpace=False,
-                    valueType=float, validator=QDoubleValidator(), orientation="horizontal", labelWidth=250,
+                    valueType=float, orientation="horizontal", labelWidth=250,
                           callback=self.setdistance)
         self.show_at(self.unitFlags()[idx], box1)
 
@@ -282,7 +282,7 @@ class OWsrcalc_idpower(XoppyWidget, WidgetDecorator):
         box1 = gui.widgetBox(box)
         oasysgui.lineEdit(box1, self, "HORIZONTAL_ACCEPTANCE",
                      label=self.unitLabels()[idx], addSpace=False,
-                    valueType=float, validator=QDoubleValidator(), orientation="horizontal", labelWidth=250)
+                    valueType=float, orientation="horizontal", labelWidth=250)
         self.show_at(self.unitFlags()[idx], box1)
 
         ########
@@ -290,7 +290,7 @@ class OWsrcalc_idpower(XoppyWidget, WidgetDecorator):
         box1 = gui.widgetBox(box)
         oasysgui.lineEdit(box1, self, "VERTICAL_ACCEPTANCE",
                      label=self.unitLabels()[idx], addSpace=False,
-                    valueType=float, validator=QDoubleValidator(), orientation="horizontal", labelWidth=250)
+                    valueType=float, orientation="horizontal", labelWidth=250)
         self.show_at(self.unitFlags()[idx], box1)
 
 
@@ -299,7 +299,7 @@ class OWsrcalc_idpower(XoppyWidget, WidgetDecorator):
         box1 = gui.widgetBox(box)
         oasysgui.lineEdit(box1, self, "NUMBER_OF_POINTS_H",
                      label=self.unitLabels()[idx], addSpace=False,
-                    valueType=int, validator=QDoubleValidator(), orientation="horizontal", labelWidth=250)
+                    valueType=int, orientation="horizontal", labelWidth=250)
         self.show_at(self.unitFlags()[idx], box1)
 
         ########
@@ -307,7 +307,7 @@ class OWsrcalc_idpower(XoppyWidget, WidgetDecorator):
         box1 = gui.widgetBox(box)
         oasysgui.lineEdit(box1, self, "NUMBER_OF_POINTS_V",
                      label=self.unitLabels()[idx], addSpace=False,
-                    valueType=int, validator=QDoubleValidator(), orientation="horizontal", labelWidth=250)
+                    valueType=int, orientation="horizontal", labelWidth=250)
         self.show_at(self.unitFlags()[idx], box1)
 
         ########
@@ -315,7 +315,7 @@ class OWsrcalc_idpower(XoppyWidget, WidgetDecorator):
         box1 = gui.widgetBox(box)
         oasysgui.lineEdit(box1, self, "ELECTRON_SIGMAS",
                      label=self.unitLabels()[idx], addSpace=False,
-                    valueType=float, validator=QDoubleValidator(), orientation="horizontal", labelWidth=250)
+                    valueType=float, orientation="horizontal", labelWidth=250)
         self.show_at(self.unitFlags()[idx], box1)
 
 
@@ -381,7 +381,7 @@ class OWsrcalc_idpower(XoppyWidget, WidgetDecorator):
             box1 = gui.widgetBox(self.tab_el[element_index])
             oasysgui.lineEdit(box1, self, "EL%d_P_POSITION"%element_index,
                          label=self.unitLabels()[idx], addSpace=False,
-                        valueType=float, validator=QDoubleValidator(), orientation="horizontal", labelWidth=300)
+                        valueType=float, orientation="horizontal", labelWidth=300)
             self.show_at(self.unitFlags()[idx], box1)
 
 
@@ -394,7 +394,7 @@ class OWsrcalc_idpower(XoppyWidget, WidgetDecorator):
             box1 = gui.widgetBox(self.tab_el[element_index])
             oasysgui.lineEdit(box1, self, "EL%d_Q_POSITION"%element_index,
                          label=self.unitLabels()[idx], addSpace=False,
-                        valueType=float, validator=QDoubleValidator(), orientation="horizontal", labelWidth=300)
+                        valueType=float, orientation="horizontal", labelWidth=300)
             self.show_at(self.unitFlags()[idx], box1)
 
 
@@ -403,7 +403,7 @@ class OWsrcalc_idpower(XoppyWidget, WidgetDecorator):
             box1 = gui.widgetBox(self.tab_el[element_index])
             oasysgui.lineEdit(box1, self, "EL%d_P_FOCUS"%element_index,
                          label=self.unitLabels()[idx], addSpace=False,
-                        valueType=float, validator=QDoubleValidator(), orientation="horizontal", labelWidth=250)
+                        valueType=float, orientation="horizontal", labelWidth=250)
             self.show_at(self.unitFlags()[idx], box1)
 
             #widget index xx
@@ -411,7 +411,7 @@ class OWsrcalc_idpower(XoppyWidget, WidgetDecorator):
             box1 = gui.widgetBox(self.tab_el[element_index])
             oasysgui.lineEdit(box1, self, "EL%d_Q_FOCUS"%element_index,
                          label=self.unitLabels()[idx], addSpace=False,
-                        valueType=float, validator=QDoubleValidator(), orientation="horizontal", labelWidth=250)
+                        valueType=float, orientation="horizontal", labelWidth=250)
             self.show_at(self.unitFlags()[idx], box1)
 
             #widget index xx
@@ -419,7 +419,7 @@ class OWsrcalc_idpower(XoppyWidget, WidgetDecorator):
             box1 = gui.widgetBox(self.tab_el[element_index])
             oasysgui.lineEdit(box1, self, "EL%d_ANG"%element_index,
                          label=self.unitLabels()[idx], addSpace=False,
-                        valueType=float, validator=QDoubleValidator(), orientation="horizontal", labelWidth=250)
+                        valueType=float, orientation="horizontal", labelWidth=250)
             self.show_at(self.unitFlags()[idx], box1)
 
             #widget index xx
@@ -427,7 +427,7 @@ class OWsrcalc_idpower(XoppyWidget, WidgetDecorator):
             box1 = gui.widgetBox(self.tab_el[element_index])
             oasysgui.lineEdit(box1, self, "EL%d_THICKNESS"%element_index,
                          label=self.unitLabels()[idx], addSpace=False,
-                        valueType=float, validator=QDoubleValidator(), orientation="horizontal", labelWidth=250)
+                        valueType=float, orientation="horizontal", labelWidth=250)
             self.show_at(self.unitFlags()[idx], box1)
 
             #widget index xx
@@ -468,7 +468,7 @@ class OWsrcalc_idpower(XoppyWidget, WidgetDecorator):
         gui.separator(box1, height=7)
         oasysgui.lineEdit(box1, self, "RAY_TRACING_RUNS",
                           label=self.unitLabels()[idx], addSpace=False,
-                          valueType=int, validator=QDoubleValidator(), orientation="horizontal", labelWidth=250)
+                          valueType=int, orientation="horizontal", labelWidth=250)
         self.show_at(self.unitFlags()[idx], box1)
 
         # widget index xx
@@ -477,7 +477,7 @@ class OWsrcalc_idpower(XoppyWidget, WidgetDecorator):
         gui.separator(box1, height=7)
         oasysgui.lineEdit(box1, self, "RAY_TRACING_SEED",
                           label=self.unitLabels()[idx], addSpace=False,
-                          valueType=int, validator=QDoubleValidator(), orientation="horizontal", labelWidth=250)
+                          valueType=int, orientation="horizontal", labelWidth=250)
         self.show_at(self.unitFlags()[idx], box1)
 
         #
@@ -587,7 +587,7 @@ class OWsrcalc_idpower(XoppyWidget, WidgetDecorator):
         gui.separator(box1, height=7)
         oasysgui.lineEdit(box1, self, "RATIO_PIXELS_0",
                           label=self.unitLabels()[idx], addSpace=False,
-                          valueType=float, validator=QDoubleValidator(), orientation="horizontal", labelWidth=250)
+                          valueType=float, orientation="horizontal", labelWidth=250)
         self.show_at(self.unitFlags()[idx], box1)
 
         # widget index xx
@@ -596,7 +596,7 @@ class OWsrcalc_idpower(XoppyWidget, WidgetDecorator):
         gui.separator(box1, height=7)
         oasysgui.lineEdit(box1, self, "RATIO_PIXELS_1",
                           label=self.unitLabels()[idx], addSpace=False,
-                          valueType=float, validator=QDoubleValidator(), orientation="horizontal", labelWidth=250)
+                          valueType=float, orientation="horizontal", labelWidth=250)
         self.show_at(self.unitFlags()[idx], box1)
 
         box = gui.widgetBox(box0,"Debug")
