@@ -1,6 +1,6 @@
 import sys, os, platform
 from PyQt5.QtWidgets import QApplication
-from PyQt5.QtGui import QIntValidator, QDoubleValidator
+
 from orangewidget import gui
 from orangewidget.settings import Setting
 from oasys.widgets import gui as oasysgui, congruence
@@ -55,7 +55,7 @@ class OWws(XoppyWidget,WidgetDecorator):
         box1 = gui.widgetBox(box) 
         self.id_ENERGY = oasysgui.lineEdit(box1, self, "ENERGY",
                      label=self.unitLabels()[idx], addSpace=False,
-                    valueType=float, validator=QDoubleValidator(), orientation="horizontal", labelWidth=250)
+                    valueType=float, orientation="horizontal", labelWidth=250)
         self.show_at(self.unitFlags()[idx], box1) 
         
         #widget index 2 
@@ -63,7 +63,7 @@ class OWws(XoppyWidget,WidgetDecorator):
         box1 = gui.widgetBox(box) 
         self.id_CUR = oasysgui.lineEdit(box1, self, "CUR",
                      label=self.unitLabels()[idx], addSpace=False,
-                    valueType=float, validator=QDoubleValidator(), orientation="horizontal", labelWidth=250)
+                    valueType=float, orientation="horizontal", labelWidth=250)
         self.show_at(self.unitFlags()[idx], box1) 
         
         #widget index 3 
@@ -71,7 +71,7 @@ class OWws(XoppyWidget,WidgetDecorator):
         box1 = gui.widgetBox(box) 
         self.id_PERIOD = oasysgui.lineEdit(box1, self, "PERIOD",
                      label=self.unitLabels()[idx], addSpace=False,
-                    valueType=float, validator=QDoubleValidator(), orientation="horizontal", labelWidth=250)
+                    valueType=float, orientation="horizontal", labelWidth=250)
         self.show_at(self.unitFlags()[idx], box1) 
         
         #widget index 4 
@@ -79,7 +79,7 @@ class OWws(XoppyWidget,WidgetDecorator):
         box1 = gui.widgetBox(box) 
         self.id_N = oasysgui.lineEdit(box1, self, "N",
                      label=self.unitLabels()[idx], addSpace=False,
-                    valueType=float, validator=QDoubleValidator(), orientation="horizontal", labelWidth=250)
+                    valueType=float, orientation="horizontal", labelWidth=250)
         self.show_at(self.unitFlags()[idx], box1) 
 
         # COMMENTED AS IT IS NOT IMPLEMENTED!!
@@ -88,7 +88,7 @@ class OWws(XoppyWidget,WidgetDecorator):
         # box1 = gui.widgetBox(box)
         # oasysgui.lineEdit(box1, self, "KX",
         #              label=self.unitLabels()[idx], addSpace=False,
-        #             valueType=float, validator=QDoubleValidator(), orientation="horizontal", labelWidth=250)
+        #             valueType=float, orientation="horizontal", labelWidth=250)
         # self.show_at(self.unitFlags()[idx], box1)
         
         #widget index 6 
@@ -96,7 +96,7 @@ class OWws(XoppyWidget,WidgetDecorator):
         box1 = gui.widgetBox(box) 
         self.id_KY = oasysgui.lineEdit(box1, self, "KY",
                      label=self.unitLabels()[idx], addSpace=False,
-                    valueType=float, validator=QDoubleValidator(), orientation="horizontal", labelWidth=250)
+                    valueType=float, orientation="horizontal", labelWidth=250)
         self.show_at(self.unitFlags()[idx], box1) 
         
         #widget index 7 
@@ -104,7 +104,7 @@ class OWws(XoppyWidget,WidgetDecorator):
         box1 = gui.widgetBox(box) 
         oasysgui.lineEdit(box1, self, "EMIN",
                      label=self.unitLabels()[idx], addSpace=False,
-                    valueType=float, validator=QDoubleValidator(), orientation="horizontal", labelWidth=250)
+                    valueType=float, orientation="horizontal", labelWidth=250)
         self.show_at(self.unitFlags()[idx], box1) 
         
         #widget index 8 
@@ -112,7 +112,7 @@ class OWws(XoppyWidget,WidgetDecorator):
         box1 = gui.widgetBox(box) 
         oasysgui.lineEdit(box1, self, "EMAX",
                      label=self.unitLabels()[idx], addSpace=False,
-                    valueType=float, validator=QDoubleValidator(), orientation="horizontal", labelWidth=250)
+                    valueType=float, orientation="horizontal", labelWidth=250)
         self.show_at(self.unitFlags()[idx], box1) 
         
         #widget index 9 
@@ -120,7 +120,7 @@ class OWws(XoppyWidget,WidgetDecorator):
         box1 = gui.widgetBox(box) 
         oasysgui.lineEdit(box1, self, "NEE",
                      label=self.unitLabels()[idx], addSpace=False,
-                    valueType=int, validator=QIntValidator(), orientation="horizontal", labelWidth=250)
+                    valueType=int, orientation="horizontal", labelWidth=250)
         self.show_at(self.unitFlags()[idx], box1) 
         
         #widget index 10 
@@ -128,7 +128,7 @@ class OWws(XoppyWidget,WidgetDecorator):
         box1 = gui.widgetBox(box) 
         oasysgui.lineEdit(box1, self, "D",
                      label=self.unitLabels()[idx], addSpace=False,
-                    valueType=float, validator=QDoubleValidator(), orientation="horizontal", labelWidth=250)
+                    valueType=float, orientation="horizontal", labelWidth=250)
         self.show_at(self.unitFlags()[idx], box1) 
         
         #widget index 11 
@@ -136,7 +136,7 @@ class OWws(XoppyWidget,WidgetDecorator):
         box1 = gui.widgetBox(box) 
         oasysgui.lineEdit(box1, self, "XPC",
                      label=self.unitLabels()[idx], addSpace=False,
-                    valueType=float, validator=QDoubleValidator(), orientation="horizontal", labelWidth=250)
+                    valueType=float, orientation="horizontal", labelWidth=250)
         self.show_at(self.unitFlags()[idx], box1) 
         
         #widget index 12 
@@ -144,7 +144,7 @@ class OWws(XoppyWidget,WidgetDecorator):
         box1 = gui.widgetBox(box) 
         oasysgui.lineEdit(box1, self, "YPC",
                      label=self.unitLabels()[idx], addSpace=False,
-                    valueType=float, validator=QDoubleValidator(), orientation="horizontal", labelWidth=250)
+                    valueType=float, orientation="horizontal", labelWidth=250)
         self.show_at(self.unitFlags()[idx], box1) 
         
         #widget index 13 
@@ -152,7 +152,7 @@ class OWws(XoppyWidget,WidgetDecorator):
         box1 = gui.widgetBox(box) 
         oasysgui.lineEdit(box1, self, "XPS",
                      label=self.unitLabels()[idx], addSpace=False,
-                    valueType=float, validator=QDoubleValidator(), orientation="horizontal", labelWidth=250)
+                    valueType=float, orientation="horizontal", labelWidth=250)
         self.show_at(self.unitFlags()[idx], box1) 
         
         #widget index 14 
@@ -160,7 +160,7 @@ class OWws(XoppyWidget,WidgetDecorator):
         box1 = gui.widgetBox(box) 
         oasysgui.lineEdit(box1, self, "YPS",
                      label=self.unitLabels()[idx], addSpace=False,
-                    valueType=float, validator=QDoubleValidator(), orientation="horizontal", labelWidth=250)
+                    valueType=float, orientation="horizontal", labelWidth=250)
         self.show_at(self.unitFlags()[idx], box1) 
         
         #widget index 15 
@@ -168,7 +168,7 @@ class OWws(XoppyWidget,WidgetDecorator):
         box1 = gui.widgetBox(box) 
         oasysgui.lineEdit(box1, self, "NXP",
                      label=self.unitLabels()[idx], addSpace=False,
-                    valueType=int, validator=QIntValidator(), orientation="horizontal", labelWidth=250)
+                    valueType=int, orientation="horizontal", labelWidth=250)
         self.show_at(self.unitFlags()[idx], box1) 
         
         #widget index 16 
@@ -176,7 +176,7 @@ class OWws(XoppyWidget,WidgetDecorator):
         box1 = gui.widgetBox(box) 
         oasysgui.lineEdit(box1, self, "NYP",
                      label=self.unitLabels()[idx], addSpace=False,
-                    valueType=int, validator=QIntValidator(), orientation="horizontal", labelWidth=250)
+                    valueType=int, orientation="horizontal", labelWidth=250)
         self.show_at(self.unitFlags()[idx], box1) 
 
     def unitLabels(self):
